===============================
fabian
===============================

.. image:: https://img.shields.io/travis/ajenta/fabian.svg
        :target: https://travis-ci.org/ajenta/fabian

.. image:: https://img.shields.io/pypi/v/fabian.svg
        :target: https://pypi.python.org/pypi/fabian


Fabian is a set of common functions useful for installing webapps on Debian machines using fabric.

* Free software: BSD license
* Documentation: https://fabian.readthedocs.org.

Features
--------

* TODO
